function outEstP=Unemp_Calibration16Estim(Pos, pi_Year, per, rho, a, b, beta, phi, sigma, iota_u, nu, alpha, gma_pi, epsilon, eps_u, Ac, vrho_wu, n_SS, thetae_SS, h_SS)
% sintaxe: outEstP=Unemp_Calibration16Estim(Pos, pi_Year, per, rho, a, b, beta, phi, sigma, iota_u, nu, alpha, gma_pi, epsilon, eps_u, Ac, vrho_wu, n_SS, thetae_SS, h_SS)
%
%
%          pi_Year  = annual inflation trend
%          per      = number os periods per year
%          StrParM  = [rho, eta, a, wu, ka, b]
%          StrParC  = [beta, phi, sigma, iota_u, nu, chi, alpha, gma_pi, epsilon, eps_u, Ac]
%          SSVar    = [vrho_wu, n_SS, thetae_SS, h_SS]
% Wrote by Sergio A. Lago Alves (Jan/2017)


% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

PI_Per    = (1+pi_Year/100)^(1/per);

alphab    = alpha*(PI_Per^((phi-1)*(1-gma_pi)));
vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

k         = (1-alphab*vc*beta)*(1-alphab)/alphab/(1+phi*omega);
kw        = (1-alphab)/(1+phi*omega);

C0        = (1-alphab)/(1-alphab*vct);
C1        = (1-alphab)/(1-alphab*vc);
C2        = (1-alphab*beta)/(1-alphab*vc*beta);
C3        = (1-alpha)/(1-alphab);
C4        = C1/C2;

% Inflation steady state levels
PI_SS     = PI_Per;
Pc_SS     = (C1*(C3^(-(1+phi*omega)/(phi-1))))^(-1/phi/(1+omega));
PcH_SS    = (C0*(C3^(-(1+phi*omegat)/(phi-1))))^(-1/phi/(1+omegat));


% Maximum Inflation;
pi_Per_Max    = 100*min( ((1/alpha)^(1/(phi-1)/(1-gma_pi))) , ((1/alpha)^(1/(phi*(1+omega))/(1-gma_pi))) ) - 100;
pi_Year_Max   = 100*((1+pi_Per_Max/100)^per) - 100;

message1 = ['Inflation OK: ', num2str(pi_Year), ' < ', num2str(pi_Year_Max)];
if pi_Year>=pi_Year_Max; message1 = ['Inflation above maximum: ', num2str(pi_Year), ' >= ', num2str(pi_Year_Max)]; end;


% steady state parameters and calibration
m_SS     = rho*n_SS;

u_SS     = 1 - (1-rho)*n_SS;
ue_SS    = 1 - n_SS;
p_SS     = m_SS/u_SS;
pe_SS    = m_SS/ue_SS;

theta_SS = thetae_SS*ue_SS/u_SS;

v_SS     = theta_SS*u_SS;
q_SS     = p_SS/theta_SS;

eta      = q_SS*(theta_SS^a);

H_SS     = h_SS*n_SS;
Y_SS     = Ac*(H_SS^(1/(1+omegat)))*(PcH_SS^phi);

A(1,:)   = [1    , -vrho_wu, 0                 ];
A(2,:)   = [(1-b), -1      , b*(1-rho)*theta_SS];
A(3,:)   = [0    ,  1      , vrho/q_SS         ];
B        = Y_SS/n_SS*[0; -(b*epsilon/mu + (1-b*epsilon/mu)*C4/mu/(1+omega)); epsilon/mu];

wu = Unemp_Calibration16_A_B(1, A, B);
w_SS = Unemp_Calibration16_A_B(2, A, B);
ka = Unemp_Calibration16_A_B(3, A, B);

C_SS     = Y_SS - ka*v_SS;
Cad_SS   = (1-iota_u)*C_SS;
Yc_SS    = C_SS;

sc        = C_SS/Y_SS;

chi      = (1-b*epsilon/mu)/mu/(1-b)/(1+omega)...
          *(C3^((1+phi*omega)/(phi-1)))/C2*eps_u*(Ac^(1+omega))...
          *(Y_SS^(-omega))*(Cad_SS^(-sigma));

StrParM    = [rho, eta, a, wu, ka, b];
StrParC    = [beta, phi, sigma, iota_u, nu, chi, alpha, gma_pi, epsilon, eps_u, Ac];

StrParCn    = StrParC;
StrParCn(7) = 0;

clear('out');

fun       = @(GUESS) Unemp_Function16(pi_Year, per, StrParM, StrParCn, GUESS);
out       = fsolve(fun,guess);

Yn_SS     = out(1);
thetan_SS = out(2);

qn_SS     = eta*(thetan_SS^(-a));
pn_SS     = eta*(thetan_SS^(1-a));
nn_SS     = pn_SS/(rho + (1-rho)*pn_SS);
vn_SS     = rho*nn_SS*thetan_SS/pn_SS;
Cn_SS     = Yn_SS - ka*vn_SS;
Cnad_SS   = (1-iota_u)*Cn_SS;

Hn_SS     = ((Yn_SS/Ac)^(1+omegat));
hn_SS     = Hn_SS/nn_SS;

disutn_SS = chi/(1+nu)*((Yn_SS/Ac)^(1+omega));
wn_SS     = epsilon/mu*Yn_SS/nn_SS - vrho*ka/qn_SS;
wagen_SS  = wn_SS/hn_SS;

scn       = Cn_SS/Yn_SS;

% steady state parameters
PI_SS    = PI_Per;
X_SS     = Y_SS/Yn_SS;
Xc_SS    = C_SS/Cn_SS;
Q_SS     = beta/PI_SS;
I_SS     = PI_SS/beta;

N_SS     = (1-b*epsilon/mu)/(1-alphab*beta*vc)*(X_SS^omega)*(Xc_SS^sigma);
D_SS     = (1-b*epsilon/mu)/(1-alphab*beta);

disut_SS = chi/(1+nu)*((Y_SS/Ac)^(1+omega))*(Pc_SS^(-phi*(1+omega)));

if sigma~=1
    util_SS  = eps_u/(1-sigma)*((Cad_SS^(1-sigma))-1);
else
    util_SS  = eps_u*log(Cad_SS);
end;

mutil_SS   = eps_u*(Cad_SS^(-sigma));
mutiln_SS  = eps_u*(Cnad_SS^(-sigma));

u_SS     = 1-(1-rho)*n_SS;
ue_SS    = 1 - n_SS;

m_SS     = rho*n_SS;
pe_SS    = m_SS/ue_SS;
thetae_SS = theta_SS*(1+pe_SS);

H_SS     = ((Y_SS/Ac)^(1+omegat))*(PcH_SS^(-phi*(1+omegat)));
h_SS     = H_SS/n_SS;

w_SS     = epsilon/mu*Y_SS/n_SS - vrho*ka/q_SS;
wage_SS  = w_SS/h_SS;

Welf_SS  = (1/(1-beta))*(util_SS-disut_SS);

sf_SS    = ka/beta/(1-b)/q_SS;
uf_SS    = b*sf_SS;
jf_SS    = (1-b)*sf_SS;

sfn_SS   = ka/beta/(1-b)/qn_SS;
ufn_SS   = b*sfn_SS;
jfn_SS   = (1-b)*sfn_SS;

clear('out');

% Output

outEst(1)  = chi;
outEst(2)  = eta;
outEst(3)  = wu;
outEst(4)  = ka;
outEst(5)  = Y_SS;
outEst(6)  = C_SS;
outEst(7)  = theta_SS;
outEst(8)  = p_SS;
outEst(9)  = q_SS;
outEst(10) = n_SS;
outEst(11) = w_SS;
outEst(12) = sc;
outEst(13) = disut_SS;
outEst(14) = mutil_SS;
outEst(15) = Yn_SS;
outEst(16) = Cn_SS;
outEst(17) = thetan_SS;
outEst(18) = pn_SS;
outEst(19) = qn_SS;
outEst(20) = nn_SS;
outEst(21) = wn_SS;
outEst(22) = scn;
outEst(23) = disutn_SS;
outEst(24) = mutiln_SS;

outEstP = outEst(Pos);

