function out=Unemp_Function16(pi_Year, per, StrParM, StrParC, GUESS)
% syntax:  out=Unemp_Function16(pi_Year, per, StrParM, StrParC, GUESS)
%          GUESS        = [Y_SS, theta_SS]
%          pi_Year      = annual inflation trend
%          per          = number os periods per year
%          StrParM      = [rho, eta, a, wu, ka, b]
%          StrParC      = [beta, phi, sigma, iota_u, nu, chi, alpha, gma_pi, epsilon, eps_u, Ac]
% Wrote by Sergio A. Lago Alves (feb/2016)

rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
alpha     = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);

% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

PI_Per    = (1+pi_Year/100)^(1/per);

alphab    = alpha*(PI_Per^((phi-1)*(1-gma_pi)));
vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

k         = (1-alphab*vc*beta)*(1-alphab)/alphab/(1+phi*omega);
kw        = (1-alphab)/(1+phi*omega);

C0        = (1-alphab)/(1-alphab*vct);
C1        = (1-alphab)/(1-alphab*vc);
C2        = (1-alphab*beta)/(1-alphab*vc*beta);
C3        = (1-alpha)/(1-alphab);
C4        = C1/C2;

% Inflation steady state levels
PI_SS     = PI_Per;
Pc_SS     = (C1*(C3^(-(1+phi*omega)/(phi-1))))^(-1/phi/(1+omega));
PcH_SS    = (C0*(C3^(-(1+phi*omegat)/(phi-1))))^(-1/phi/(1+omegat));

% evaluating the (1x3) nonlinear system
Y_SS     = GUESS(1);
theta_SS = GUESS(2);


q_SS     = eta*(theta_SS^(-a));
p_SS     = eta*(theta_SS^(1-a));
n_SS     = p_SS/(rho + (1-rho)*p_SS);
v_SS     = rho*n_SS*theta_SS/p_SS;
C_SS     = Y_SS - ka*v_SS;
Cad_SS   = (1-iota_u)*C_SS;


out(1,1) =  (Y_SS^omega)*(Cad_SS^sigma)...
          - (1-b*epsilon/mu)/mu/chi/(1-b)/(1+omega)...
           *(C3^((1+phi*omega)/(phi-1)))/C2*eps_u*(Ac^(1+omega));

out(1,2) =  vrho*ka/q_SS - ((1-b)*epsilon/mu - (1-b*epsilon/mu)*C4/mu/(1+omega))*Y_SS/n_SS...
          + b*(1-rho)*ka*theta_SS + (1-b)*wu;
      

     