function out=Unemp_Function16_Rotemberg(pi_Year, per, StrParM, StrParC, GUESS)
% syntax:  out=Unemp_Function16_Rotemberg(pi_Year, per, StrParM, StrParC, GUESS)
%          GUESS        = [Y_SS, theta_SS]
%          pi_Year      = annual inflation trend
%          per          = number os periods per year
%          StrParM      = [rho, eta, a, wu, ka, b]
%          StrParC  = [beta, phi, sigma, iota_u, nu, chi, k_pi, gma_pi, epsilon, eps_u, Ac]
% Wrote by Sergio A. Lago Alves (Oct/2016)


rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
k_pi      = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);


% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

Sf1       = epsilon/chi/mu/((1-iota_u)^sigma);
Mf1       = (1+nu)*(1-b)/(1-b*epsilon/mu);

PI_Per    = (1+pi_Year/100)^(1/per);

vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));
dc        = PI_Per^((phi-1)*(1-gma_pi));
df        = PI_Per^(1-gma_pi);

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

R0        = PI_Per^(1+gma_pi);
R1        = 1 + 1/(1-b*epsilon/mu)*(1-beta)/(phi-1)*(df-1)*R0/k_pi;
k_r       = (phi-1)*(1-b*epsilon/mu)*k_pi/(2*df-1)*R1/R0;
gma_r     = gma_pi/(2*df-1);


% Inflation steady state levels
PI_SS     = PI_Per;
pc_SS     = 1;
Pc_SS     = 1;
PcH_SS    = 1;

% evaluating the (1x3) nonlinear system
Y_SS     = GUESS(1);
theta_SS = GUESS(2);


q_SS     = eta*(theta_SS^(-a));
p_SS     = eta*(theta_SS^(1-a));
n_SS     = p_SS/(rho + (1-rho)*p_SS);
v_SS     = rho*n_SS*theta_SS/p_SS;
C_SS     = Y_SS - ka*v_SS;
Cad_SS   = (1-iota_u)*C_SS;


out(1,1) =  (Y_SS^omega)*(C_SS^sigma)...
          - Sf1*R1/Mf1...
           *eps_u*(Ac^(1+omega));

out(1,2) =  vrho*ka/q_SS - (1-b)*epsilon/mu*(1 - R1/Mf1)*Y_SS/n_SS...
          + b*(1-rho)*ka*theta_SS + (1-b)*wu;
      
      
      
      
      
      
      
      
      

     