function out=Unemp_Function16_Taylor(pi_Year, per, StrParM, StrParC, GUESS)
% syntax:  out=Unemp_Function16_Taylor(pi_Year, per, StrParM, StrParC, GUESS)
%          GUESS        = [Y_SS, theta_SS]
%          pi_Year      = annual inflation trend
%          per          = number os periods per year
%          StrParM      = [rho, eta, a, wu, ka, b]
%          StrParC      = [beta, phi, sigma, iota_u, nu, chi, Tc, gma_pi, epsilon, eps_u, Ac]
% Wrote by Sergio A. Lago Alves (Oct/2016)

rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
Tc        = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);

% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

Sf1       = epsilon/chi/mu/((1-iota_u)^sigma);
Mf1       = (1+nu)*(1-b)/(1-b*epsilon/mu);

PI_Per    = (1+pi_Year/100)^(1/per);

vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));
dc        = PI_Per^((phi-1)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

T0 = Tc; T3 = Tc; T4 = Tc;
if PI_Per~=1;  T0 = ((dc)^Tc-1)/((dc)-1); end;
T1        = ((beta*dc)^Tc-1)/((beta*dc)-1);
T2        = ((beta*dc*vc)^Tc-1)/((beta*dc*vc)-1);
if PI_Per~=1;  T3        = ((dc*vc)^Tc-1)/((dc*vc)-1); end;
if PI_Per~=1;  T4        = ((dc*vct)^Tc-1)/((dc*vct)-1); end;
T5        = T2*T4/T1/T3;

% Inflation steady state levels
PI_SS     = PI_Per;
pc_SS     = (T0/Tc)^(1/(phi-1));
Pc_SS     = pc_SS*((T3/Tc)^(-1/phi/(1+omega)));
PcH_SS    = pc_SS*((T4/Tc)^(-1/phi/(1+omegat)));

% evaluating the (1x3) nonlinear system
Y_SS     = GUESS(1);
theta_SS = GUESS(2);


q_SS     = eta*(theta_SS^(-a));
p_SS     = eta*(theta_SS^(1-a));
n_SS     = p_SS/(rho + (1-rho)*p_SS);
v_SS     = rho*n_SS*theta_SS/p_SS;
C_SS     = Y_SS - ka*v_SS;
Cad_SS   = (1-iota_u)*C_SS;


out(1,1) =  (Y_SS^omega)*(C_SS^sigma)...
          - ((T0/Tc)^((1+phi*omega)/(phi-1)))*(T1/T2)*(Sf1/Mf1)...
           *eps_u*(Ac^(1+omega));

out(1,2) =  vrho*ka/q_SS - (1-b)*epsilon/mu*(1 - T5/Mf1)*Y_SS/n_SS...
          + b*(1-rho)*ka*theta_SS + (1-b)*wu;
      
      
      
      
      
      
      
      
      

     