function out=Unemp_Parameters16_Taylor(pi_Year, per, StrParM, StrParC)
% sintaxe: out=Unemp_Parameters16_Taylor(pi_Year, per, StrParM, StrParC)

%          pi_Year  = annual inflation trend
%          per      = number os periods per year
%          Tc       = number os periods between optimizations
%          StrParM  = [rho, eta, a, wu, ka, b]
%          StrParC  = [beta, phi, sigma, iota_u, nu, chi, Tc, gma_pi, epsilon, eps_u, Ac]
% Wrote by Sergio A. Lago Alves (Oct/2016)

rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
Tc        = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);

% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

Sf1       = epsilon/chi/mu/((1-iota_u)^sigma);
Mf1       = (1+nu)*(1-b)/(1-b*epsilon/mu);

PI_Per    = (1+pi_Year/100)^(1/per);

vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));
dc        = PI_Per^((phi-1)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

T0 = Tc; T3 = Tc; T4 = Tc;
if PI_Per~=1;  T0 = ((dc)^Tc-1)/((dc)-1); end;
T1        = ((beta*dc)^Tc-1)/((beta*dc)-1);
T2        = ((beta*dc*vc)^Tc-1)/((beta*dc*vc)-1);
if PI_Per~=1;  T3        = ((dc*vc)^Tc-1)/((dc*vc)-1); end;
if PI_Per~=1;  T4        = ((dc*vct)^Tc-1)/((dc*vct)-1); end;
T5        = T2*T4/T1/T3;

% Inflation steady state levels
PI_SS     = PI_Per;
pc_SS     = (T0/Tc)^(1/(phi-1));
Pc_SS     = pc_SS*((T3/Tc)^(-1/phi/(1+omega)));
PcH_SS    = pc_SS*((T4/Tc)^(-1/phi/(1+omegat)));

% Maximum Inflation;
pi_Per_Max    = inf;
pi_Year_Max   = 100*((1+pi_Per_Max/100)^per) - 100;

% solving the nonlinear system

sc_gss    = 0.95;

Y_gss     = ( ((T0/Tc)^((1+phi*omega)/(phi-1)))*(T1/T2)*(Sf1/Mf1)...
               *eps_u*(Ac^(1+omega))*sc_gss^(-sigma) )^(1/(sigma+omega));

n_gss     = 0.943;
p_gss     = rho*n_gss/(1-(1-rho)*n_gss);
theta_gss = (p_gss/eta)^(1/(1-a));

guess     = [Y_gss, theta_gss];
  
fun       = @(GUESS) Unemp_Function16_Taylor(pi_Year, per, StrParM, StrParC, GUESS);
out       = fsolve(fun,guess);

Y_SS      = out(1);
theta_SS  = out(2);

q_SS      = eta*(theta_SS^(-a));
p_SS      = eta*(theta_SS^(1-a));
n_SS      = p_SS/(rho + (1-rho)*p_SS);
v_SS      = rho*n_SS*theta_SS/p_SS;
C_SS      = Y_SS - ka*v_SS;
Cad_SS    = (1-iota_u)*C_SS;

sc        = C_SS/Y_SS;

StrParCn    = StrParC;
StrParCn(7) = 1;

clear('out');

fun       = @(GUESS) Unemp_Function16_Taylor(pi_Year, per, StrParM, StrParCn, GUESS);
out       = fsolve(fun,guess);

Yn_SS     = out(1);
thetan_SS = out(2);

qn_SS     = eta*(thetan_SS^(-a));
pn_SS     = eta*(thetan_SS^(1-a));
nn_SS     = pn_SS/(rho + (1-rho)*pn_SS);
vn_SS     = rho*nn_SS*thetan_SS/pn_SS;
Cn_SS     = Yn_SS - ka*vn_SS;
Cnad_SS   = (1-iota_u)*Cn_SS;

Hn_SS     = ((Yn_SS/Ac)^(1+omegat));
hn_SS     = Hn_SS/nn_SS;

disutn_SS = chi/(1+nu)*((Yn_SS/Ac)^(1+omega));
wn_SS     = epsilon/mu*Yn_SS/nn_SS - vrho*ka/qn_SS;
wagen_SS  = wn_SS/hn_SS;

scn       = Cn_SS/Yn_SS;

% steady state parameters
PI_SS    = PI_Per;
X_SS     = Y_SS/Yn_SS;
Xc_SS    = C_SS/Cn_SS;
Q_SS     = beta/PI_SS;
I_SS     = PI_SS/beta;

N_SS     = (1-b*epsilon/mu)*T2*(X_SS^omega)*(Xc_SS^sigma);
D_SS     = (1-b*epsilon/mu)*T1;

disut_SS = chi/(1+nu)*((Y_SS/Ac)^(1+omega))*(Pc_SS^(-phi*(1+omega)));

if sigma~=1
    util_SS  = eps_u/(1-sigma)*((Cad_SS^(1-sigma))-1);
else
    util_SS  = eps_u*log(Cad_SS);
end;

mutil_SS   = eps_u*(Cad_SS^(-sigma));
mutiln_SS  = eps_u*(Cnad_SS^(-sigma));

u_SS     = 1-(1-rho)*n_SS;
ue_SS    = 1 - n_SS;

m_SS     = rho*n_SS;
pe_SS    = m_SS/ue_SS;
thetae_SS = theta_SS*(1+pe_SS);

H_SS     = ((Y_SS/Ac)^(1+omegat))*(PcH_SS^(-phi*(1+omegat)));
h_SS     = H_SS/n_SS;

w_SS     = epsilon/mu*Y_SS/n_SS - vrho*ka/q_SS;
wage_SS  = w_SS/h_SS;

Welf_SS  = (1/(1-beta))*(util_SS-disut_SS);

sf_SS    = ka/beta/(1-b)/q_SS;
uf_SS    = b*sf_SS;
jf_SS    = (1-b)*sf_SS;

sfn_SS   = ka/beta/(1-b)/qn_SS;
ufn_SS   = b*sfn_SS;
jfn_SS   = (1-b)*sfn_SS;

clear('out');

% Output
out.Yn_SS     = Yn_SS;
out.Cn_SS     = Cn_SS;
out.Cnad_SS   = Cnad_SS;
out.scn       = scn;
out.Hn_SS     = Hn_SS;
out.hn_SS     = hn_SS;

out.wn_SS     = wn_SS;
out.wagen_SS  = wagen_SS;

out.nn_SS     = nn_SS;
out.un_SS     = 1-(1-rho)*nn_SS;
out.uen_SS    = 1 - nn_SS;
out.vn_SS     = vn_SS;
out.qn_SS     = qn_SS;
out.pn_SS     = pn_SS;
out.thetan_SS = thetan_SS;
out.disutn_SS = disutn_SS;

out.Y_SS      = Y_SS;
out.C_SS      = C_SS;
out.Cad_SS    = Cad_SS;
out.sc        = sc;
out.H_SS      = H_SS;
out.h_SS      = h_SS;

out.w_SS      = w_SS;
out.wage_SS   = wage_SS;

out.I_SS      = I_SS;
out.Q_SS      = Q_SS;

out.pc_SS     = pc_SS;
out.Pc_SS     = Pc_SS;
out.PcH_SS    = PcH_SS;
out.pi_Year_Max = pi_Year_Max;

out.n_SS      = n_SS;
out.u_SS      = u_SS;
out.ue_SS     = ue_SS;
out.v_SS      = v_SS;
out.q_SS      = q_SS;
out.p_SS      = p_SS;
out.pe_SS     = pe_SS;
out.theta_SS  = theta_SS;
out.thetae_SS = thetae_SS;

out.disut_SS  = disut_SS;
out.util_SS   = util_SS;
out.Welf_SS   = Welf_SS;
out.mutil_SS  = mutil_SS;
out.mutiln_SS = mutiln_SS;

out.sf_SS     = sf_SS;
out.uf_SS     = uf_SS;
out.jf_SS     = jf_SS;

out.sfn_SS    = sfn_SS;
out.ufn_SS    = ufn_SS;
out.jfn_SS    = jfn_SS;










