function out=Unemp_Welfare16_AllPar(N, pi_YRange, pi_Year, per, StrParM, StrParC, SSVar)
% syntax: out=Unemp_Welfare16_AllPar(N, pi_YRange, pi_Year, per, StrParM, StrParC, SSVar)
%          out       = (Nx3) vector containing [piY, W, Y, Yn]
%                      where W is the vector of welfare at each trend
%                      inflation piY, Y is the output, Yn is the natural
%                      output
%          N         = number of points to evaluate the inflation trend in
%                      the range pi_YRange
%          pi_Year  = annual inflation trend
%          per      = number os periods per year
%          StrParM  = [rho, eta, a, wu, ka, b]
%          StrParC  = [beta, phi, sigma, iota_u, nu, chi, alpha, gma_pi, epsilon, eps_u, Ac]
%          SSVar    = [vrho_wu, n_SS, thetae_SS, h_SS]
% Wrote by Sergio A. Lago Alves (Feb/2016)
%
% initial:    use Unemp_Calibration13 to calibrate the parameters
% suggestion: increase sigma1 (5.5), reduce theta


% needNewWorkers = (matlabpool('size') == 0);
% if needNewWorkers; matlabpool open; end;

bmax     = 0.7;
bN       = 300;
bRange   = (1:bN*bmax)/bN;

StrParM_BM = StrParM;
StrParC_BM = StrParC;
SSVar_BM   = SSVar;
    
rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
alpha     = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);

% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

PI_Per    = (1+pi_Year/100)^(1/per);

alphab    = alpha*(PI_Per^((phi-1)*(1-gma_pi)));
vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

k         = (1-alphab*vc*beta)*(1-alphab)/alphab/(1+phi*omega);
kw        = (1-alphab)/(1+phi*omega);

C0        = (1-alphab)/(1-alphab*vct);
C1        = (1-alphab)/(1-alphab*vc);
C2        = (1-alphab*beta)/(1-alphab*vc*beta);
C3        = (1-alpha)/(1-alphab);
    
% Inflation steady state levels
PI_SS     = PI_Per;
Pc_SS     = (C1*(C3^(-(1+phi*omega)/(phi-1))))^(-1/phi/(1+omega));
PcH_SS    = (C0*(C3^(-(1+phi*omegat)/(phi-1))))^(-1/phi/(1+omegat));

% Maximum Inflation;
pi_Per_Max  = 100*min( ((1/alpha)^(1/(phi-1)/(1-gma_pi))) , ((1/alpha)^(1/(phi*(1+omega))/(1-gma_pi))) ) - 100;
pi_Year_Max = 100*((1+pi_Per_Max/100)^per) - 100; 




lin   = 3; col = 4;
ti    = zeros(lin*col,4);
po    = zeros(lin*col,4);

fonsize    = 12;
fonsizeTtl = 10;
fonsizeAxe = 10;

figure;
    
for index=1:(lin*col)
    subplot(lin,col,index);
        title({'bogus';'bogus'},'FontSize', fonsize);
        set(gca,'fontsize',fonsizeAxe)

    ti(index, :) = get(gca,'TightInset');
    po(index, :) = get(gca,'Position');
end;
    
PO = po;

IncH1 = 1.5*(fonsize/10);
IncH3 = 1+0*(fonsize/10);

IncV2 = 0.8*2+0*(fonsize/10);
IncV4 = 0.35*1.4+0*(fonsize/10);

referH = max(IncH1*ti(col*(0:(lin-1)) + 1 , 1));
PO( col*(0:(lin-1)) + 1 , 1) = referH;

referV = max(IncV2*ti((1:col) + (lin-1)*col , 2));
PO( (1:col) + (lin-1)*col , 2) = referV;

for c=2:col
    referH = referH + max(po(col*(0:(lin-1)) + (c-1) , 3) + IncH3*ti(col*(0:(lin-1)) + (c-1) , 3)) ...
                    + max(IncH1*ti(col*(0:(lin-1)) + c , 1));
    PO( col*(0:(lin-1)) + c , 1) = referH;
end;
    
for l=2:lin
    referV = referV + max(po((1:col) + (lin-(l-1))*col , 4) + IncV4*ti((1:col) + (lin-(l-1))*col , 4)) ...
                    + max(IncV2*ti((1:col) + (lin-l)*col , 2));
    PO( (1:col) + (lin-l)*col , 2) = referV;
end;

% Now I renormalize the widths and heights:

referH  = referH + max(po(col*(0:(lin-1)) + col , 3) + IncH3*ti(col*(0:(lin-1)) + col , 3));
PO(:,3) = PO(:,3) + (1-referH)/col;

referV  = referV + max(po(1:col , 4) + IncV4*ti(1:col , 4));
PO(:,4) = PO(:,4) + (1-referV)/lin;

for c=2:col
    PO( col*(0:(lin-1)) + c , 1) = PO( col*(0:(lin-1)) + c , 1) + (c-1)*(1-referH)/col;
end;

for l=2:lin
    PO( (1:col) + (lin-l)*col , 2) = PO( (1:col) + (lin-l)*col , 2) + (l-1)*(1-referV)/lin;
end;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%/
%%% Computing simulations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

piCritY     = pi_Year;
piCrit      = floor(piCritY);

pi_Range     = sort([pi_Year, linspace(pi_YRange(1,1), pi_YRange(1,2), N)]);
% piY(:,ll)   = piY(piY(:,ll)<=pi_Year_Max);

pi_size     = size(pi_Range,2);
pi_count    = 1:pi_size;


%%%%%  StrParM  = [rho, eta, a, wu, ka, b];
%%%                1    2    3  4   5   6

%%%%  StrParC  = [beta, phi, sigma, iota_u, nu, chi, alpha, gma_pi, epsilon, eps_u, Ac];
%%%               1     2    3      4       5   6    7      8       9        10     11

%%%%  SSVar    = [vrho_wu, n_SS   , thetae_SS, h_SS]
%%%                1        2        3          4


ParNames  = { {'\rho', 'a', 'b'},...
              {'\beta', '\phi', '\sigma', '\iota_u', '\nu', '\alpha', '\gamma_{\pi}', '\epsilon'},...
              {'\rho_{wu}'} };

ParPoss   = { [1, 3, 6],...
              [1, 2, 3, 4, 5, 7, 8, 9],...
              [1] };

ParVecs   = {'M', 'C', 'V'};

NPar        = 30;

Par_Ranges{1} = {linspace(0.05, 0.30, NPar), ...
                 linspace(0.30, 0.60, NPar), ...
                 linspace(0.30, 0.60, NPar)};

Par_Ranges{2} = {linspace(0.95, 0.999, NPar), ...
                 linspace(6.00, 9.00, NPar), ...
                 linspace(0.50, 2.00, NPar), ...
                 linspace(0.50, 0.90, NPar), ...
                 linspace(1.50, 3.00, NPar), ...
                 linspace(0.60, 0.75, NPar), ...
                 linspace(0.10, 0.40, NPar), ...
                 linspace(0.60, 0.80, NPar)};

Par_Ranges{3} = {linspace(0.20, 0.50, NPar)};


sf_range      = [ 0.67, 1.65;...
                  0.84, 1.04;...
                  0.30, 2.25;...
                  0.24, 1.13;...
                  0.49, 1.02;...
                  0.84, 1.02;...
                  0.84, 1.02;...
                  0.01, 1.50;...
                  0.75, 1.03;...
                  0.73, 1.02;...
                  0.68, 1.61;...
                  0.21, 2.23];                  


CountAgg  = 0;

ParTpeSze = size(ParVecs, 2);

sf   = zeros(1, (1+pi_size) ); % first position is meant for flexible prices equilibrium

for ParTpe=1:ParTpeSze                               %%%%%%%%%%%%%% New For

ParVec    = ParVecs{ParTpe};

ParPosSze = size(ParPoss{ParTpe}, 2);



for ParPosp=1:ParPosSze                              %%%%%%%%%%%%%% New For

CountAgg = CountAgg + 1;

ParPos  = ParPoss{ParTpe}(ParPosp);
ParName = ParNames{ParTpe}{ParPosp};

if     ParVec=='C'; ParBM = StrParC(ParPos);
elseif ParVec=='M'; ParBM = StrParM(ParPos);
else              ; ParBM = SSVar(ParPos); end;

Par_Range   = [ParBM , Par_Ranges{ParTpe}{ParPosp} , ParBM];
% Par_Range = ParBM;

ParTitle = {[ParName, ' = ', num2str(ParBM)]; 'Benchmark'};

aa = 0.12*(sf_range(CountAgg,2) - sf_range(CountAgg,1));
bb = sf_range(CountAgg,2) + aa;
cc = bb + (sf_range(CountAgg,2) - sf_range(CountAgg,1))/3;
LegendRange = linspace(bb, cc, NPar);
sf_range(CountAgg,2) = cc + aa;
sf_range(CountAgg,1) = sf_range(CountAgg,1) - aa;

countPar  = 0;
countPPar = 0;
countTot  = 0;

ParBMTest = 0;

for ParVlu=Par_Range                                 %%%%%%%%%%%%%% New For

countPPar = countPPar + 1;
if ParVlu~=ParBM; countPar = countPar + 1; end;

StrParM = StrParM_BM;
StrParC = StrParC_BM;
SSVar   = SSVar_BM;

ColPwr   = 1.25;
ColRed   = ((countPar-1)/(NPar-1))^ColPwr;
ColRed   = min(max(ColRed, 0), 1);
ColBlu   = 1 - ColRed;
ColVec   = ColRed*[1, 0, 0] + ColBlu*[0, 0, 1];

if     ParVec=='C'; StrParC(ParPos) = ParVlu;
elseif ParVec=='M'; StrParM(ParPos) = ParVlu;
else              ; SSVar(ParPos)   = ParVlu; end;

fi    = StrParC(2);
nue   = StrParC(5);
alfa  = StrParC(7);
gm_pi = StrParC(8);
epsln = StrParC(9);

pi_Per_Max    = 100*min( ((1/alfa)^(1/(fi-1)/(1-gm_pi))) , ((1/alfa)^(1/(fi*(1+((1/epsln)*(1+nue)-1)))/(1-gm_pi))) ) - 100;
pi_Year_Max   = 100*((1+pi_Per_Max/100)^per) - 100;

pi_Thresh  = 0.3;

count = 0;

for piyear=pi_Range                                  %%%%%%%%%%%%%% New For

    pi_year = min(piyear, pi_Year_Max - pi_Thresh);
    piCrt_Y = min(piCritY, pi_Year_Max - pi_Thresh);

    count    = count + 1;
    countTot = countTot + 1;

    clc;
    disp([ParName, ' = ', num2str(ParVlu)]);
    disp(['Running = ', num2str(floor(1000*count/size(pi_Range,2))/10), ' / 100']);
    disp(['RunTotl = ', num2str(floor(1000*countTot/size(pi_Range,2)/(NPar+1))/10), ' / 100']);

    StPrC   = StrParC;
    StPrM   = StrParM;
    SSV     = SSVar;

    out     = Unemp_Calibration16(piCrt_Y*0 + pi_year, per, StPrM, StPrC, SSV);
    StPrM   = out.StrParM;
    StPrC   = out.StrParC;
    StPrCn  = StPrC; StPrCn(7) = 0;

    out     = Unemp_Parameters16(pi_year, per, StPrM, StPrC);

    sf(1,(1+count)) = out.sf_SS;
    if count==1;   %%% flexible prices
        sf(1,1) = out.sfn_SS;
        if ParVlu==ParBM; sfNorm = out.sf_SS; end;
    end;

end;

sfN = sf/sfNorm;


% Now I draw the plots:


index=1;

    sfN_Pi  = sfN(1, 2:end);
    sfN_n   = sfN(1, 1);

    subplot(lin,col,CountAgg);

        if ParVlu==ParBM && ParBMTest==0
            
            ParBMTest = 1;

            plot(pi_Range, sfN_Pi, '-k', 'LineWidth', 2.5); hold on;
            plot(piCritY , sfN_Pi(pi_Range==piCritY), '*k');
            plot(piCritY , sfN_Pi(pi_Range==piCritY), 'sk');
            
            LegendPos = min(LegendRange) + ...
                        (max(LegendRange)-min(LegendRange))...
                       *(ParVlu-min(Par_Range))/(max(Par_Range)-min(Par_Range));

            plot([0, 0.65], [LegendPos, LegendPos], '-k', 'LineWidth', 2.5);

            
        elseif ParVlu~=ParBM

            plot(pi_Range(pi_Range<(pi_Year_Max - pi_Thresh)),...
                   sfN_Pi(pi_Range<(pi_Year_Max - pi_Thresh)), '-', 'color', ColVec); hold on;
            
            plot([0, 0.5], [LegendRange(countPar), LegendRange(countPar)], '-', 'color', ColVec);
            
            
            if ParVlu==min(Par_Range) || ParVlu==max(Par_Range)
        	
                LegendPos = min(LegendRange) + ...
                         (max(LegendRange)-min(LegendRange))...
                        *(ParVlu-min(Par_Range))/(max(Par_Range)-min(Par_Range));

                text(0.7, LegendPos, num2str(ParVlu),...
                        'FontSize',9,'VerticalAlignment','middle');
                    
            end;
            
            
        end;

        xlim([-0.2, 4]); ylim(sf_range(CountAgg,:));        

        title(ParTitle,'FontSize', fonsize);
        xlabel('Trend Inflation','FontSize', fonsizeAxe);
        ylabel('Normalized Total Surplus','FontSize', fonsizeAxe);

end;

end;

end;

% Now I rescale the subplots:

for index=1:(lin*col)
    subplot(lin,col,index);
    set(gca,'Position',PO(index,:));
end;



