function out=Unemp_Welfare16_Taylor(N, pi_YRange, pi_Year, per, StrParM, StrParC, SSVar, fig)
% syntax: out=Unemp_Welfare16_Taylor(N, pi_YRange, pi_Year, per, StrParM, StrParC, SSVar, fig)
%          out       = (Nx3) vector containing [piY, W, Y, Yn]
%                      where W is the vector of welfare at each trend
%                      inflation piY, Y is the output, Yn is the natural
%                      output
%          N         = number of points to evaluate the inflation trend in
%                      the range pi_YRange
%          pi_Year  = annual inflation trend
%          per      = number os periods per year
%          StrParM  = [rho, eta, a, wu, ka, b]
%          StrParC  = [beta, phi, sigma, iota_u, nu, chi, Tc, gma_pi, epsilon, eps_u, Ac]
%          SSVar    = [vrho_wu, n_SS, thetae_SS, h_SS]
% Wrote by Sergio A. Lago Alves (Oct/2016)
%
% initial:    use Unemp_Calibration13 to calibrate the parameters
% suggestion: increase sigma1 (5.5), reduce theta


% needNewWorkers = (matlabpool('size') == 0);
% if needNewWorkers; matlabpool open; end;

bmax     = 0.7;
bN       = 300;
bRange   = (1:bN*bmax)/bN;
    
rho       = StrParM(1);
eta       = StrParM(2);
a         = StrParM(3);
wu        = StrParM(4);
ka        = StrParM(5);
b         = StrParM(6); 

beta      = StrParC(1);
phi       = StrParC(2);
sigma     = StrParC(3); % risk aversion
iota_u    = StrParC(4); 
nu        = StrParC(5);
chi       = StrParC(6);
Tc        = StrParC(7);
gma_pi    = StrParC(8);
epsilon   = StrParC(9);
eps_u     = StrParC(10);
Ac        = StrParC(11);

% composite parameters
mu        = phi/(phi-1);
vrho      = (1-beta)/beta + rho;
omega     = (1/epsilon)*(1+nu)-1;
omegat    = (1/epsilon)-1;

Sf1       = epsilon/chi/mu/((1-iota_u)^sigma);
Mf1       = (1+nu)*(1-b)/(1-b*epsilon/mu);

PI_Per    = (1+pi_Year/100)^(1/per);

vc        = PI_Per^((1+phi*omega)*(1-gma_pi));
vct       = PI_Per^((1+phi*omegat)*(1-gma_pi));
dc        = PI_Per^((phi-1)*(1-gma_pi));

bf2       = mu*(1+nu)*(1+omega);
bf1       = (1+nu)*(1-b) + b*bf2;

T0 = Tc; T3 = Tc; T4 = Tc;
if PI_Per~=1;  T0 = ((dc)^Tc-1)/((dc)-1); end;
T1        = ((beta*dc)^Tc-1)/((beta*dc)-1);
T2        = ((beta*dc*vc)^Tc-1)/((beta*dc*vc)-1);
if PI_Per~=1;  T3        = ((dc*vc)^Tc-1)/((dc*vc)-1); end;
if PI_Per~=1;  T4        = ((dc*vct)^Tc-1)/((dc*vct)-1); end;
T5        = T2*T4/T1/T3;

% Inflation steady state levels
PI_SS     = PI_Per;
pc_SS     = (T0/Tc)^(1/(phi-1));
Pc_SS     = pc_SS*((T3/Tc)^(-1/phi/(1+omega)));
PcH_SS    = pc_SS*((T4/Tc)^(-1/phi/(1+omegat)));

% Maximum Inflation;
pi_Per_Max    = inf;
pi_Year_Max   = 100*((1+pi_Per_Max/100)^per) - 100;
    
piY     = sort([pi_Year, linspace(pi_YRange(1,1), pi_YRange(1,2), N)])';
% piY(:,ll)   = piY(piY(:,ll)<=pi_Year_Max);
    
N           = size(piY,1);  

out0        = Unemp_Parameters16_Taylor(pi_Year, per, StrParM, StrParC);
    sf      = repmat(out0.sf_SS, N, 1);
    u       = repmat(out0.u_SS, N, 1);
    ue      = repmat(out0.ue_SS, N, 1);
    v       = repmat(out0.v_SS, N, 1);
    theta   = repmat(out0.theta_SS, N, 1);
    thetae  = repmat(out0.thetae_SS, N, 1);
    p       = repmat(out0.p_SS, N, 1);
    q       = repmat(out0.q_SS, N, 1);
    n       = repmat(out0.n_SS, N, 1);
    h       = repmat(out0.h_SS, N, 1);
    X       = repmat(out0.Y_SS/out0.Yn_SS, N, 1);
    w       = repmat(out0.w_SS, N, 1);
    Welf    = repmat(out0.Welf_SS , N, 1);

    
for nn=1:N
    pi_Yr          = piY(nn,1);
    
    StrParM0       = StrParM;
    StrParC0       = StrParC;
        
    if 1==0
        out0       = Unemp_Calibration16_Taylor(pi_Yr, per, StrParM0, StrParC0, SSVar);
        StrParM0   = out0.StrParM;
        StrParC0   = out0.StrParC;
    end;
        
    out2           = Unemp_Parameters16_Taylor(pi_Yr, per, StrParM0, StrParC0);
        sf(nn)     = out2.sf_SS;
        u(nn)      = out2.u_SS;
        ue(nn)     = out2.ue_SS;
        v(nn)      = out2.v_SS;
        theta(nn)  = out2.theta_SS;
        thetae(nn) = out2.thetae_SS;
        p(nn)      = out2.p_SS;
        q(nn)      = out2.q_SS;
        n(nn)      = out2.n_SS;
        h(nn)      = out2.h_SS;
        X(nn)      = out2.Y_SS/out2.Yn_SS;
        w(nn)      = out2.w_SS;
        Welf(nn)   = out2.Welf_SS;
        
        
    if pi_Yr==pi_Year
        sf_PiY     = out2.sf_SS;
        u_PiY      = out2.u_SS;
        ue_PiY     = out2.ue_SS;
        v_PiY      = out2.v_SS;
        theta_PiY  = out2.theta_SS;
        thetae_PiY = out2.thetae_SS;
        p_PiY      = out2.p_SS;
        q_PiY      = out2.q_SS;
        n_PiY      = out2.n_SS;
        h_PiY      = out2.h_SS;
        X_PiY      = out2.Y_SS/out2.Yn_SS;
        w_PiY      = out2.w_SS;
    	Welf_PiY   = out2.Welf_SS;
    end;    

end;
    
sfTot          = sf.*n;
sfTot_PiY      = sf_PiY.*n_PiY;

H              = h.*n;
H_PiY          = h_PiY.*n_PiY;
    
out = 'ok';
    
if fig==1
    % http://tipstrickshowtos.blogspot.com/2010/08/how-to-get-rid-of-white-margin-in.html#!/2010/08/how-to-get-rid-of-white-margin-in.html
    % http://www.mathworks.com/help/techdoc/creating_plots/f1-32495.html
    % http://www.mathworks.com/help/techdoc/creating_plots/f5-40107.html
    % http://www.mathworks.com/help/techdoc/ref/axes_props.html?
    % http://www.mathworks.com/help/techdoc/ref/axes_props.html
    
    % Position and OuterPosition: [left bottom width height]
    %       Width and height are relative to the graph window dimensions
    %       Left and bottom are relative to the screen dimensions
    %       All are between 0 and 1 and invariant wrt the window size
    
    lin   = 3; col = 4;
    ti    = zeros(lin*col,4);
    po    = zeros(lin*col,4);
    
    fonsize    = 12;
    fonsizeTtl = 10;
    fonsizeAxe = 10;
    
    figure;
    
    for index=1:(lin*col)
        subplot(lin,col,index);
            title({'bogus';'bogus';'bogus'},'FontSize', fonsizeTtl);
            set(gca,'fontsize',fonsizeAxe)
        ti(index, :) = get(gca,'TightInset');
        po(index, :) = get(gca,'Position');
    end;
    
    PO = po;
    
    IncH1 = 1.6*(fonsize/10);
    IncH3 = 1+0*(fonsize/10);

    IncV2 = 0.8*2+0*(fonsize/10);
    IncV4 = 0.35*1.4+0*(fonsize/10);
    
    referH = max(IncH1*ti(col*(0:(lin-1)) + 1 , 1));
    PO( col*(0:(lin-1)) + 1 , 1) = referH;
    
    referV = max(IncV2*ti((1:col) + (lin-1)*col , 2));
    PO( (1:col) + (lin-1)*col , 2) = referV;
    
    for c=2:col
        referH = referH + max(po(col*(0:(lin-1)) + (c-1) , 3) + IncH3*ti(col*(0:(lin-1)) + (c-1) , 3)) ...
                        + max(IncH1*ti(col*(0:(lin-1)) + c , 1));
        PO( col*(0:(lin-1)) + c , 1) = referH;
    end;
    
    for l=2:lin
        referV = referV + max(po((1:col) + (lin-(l-1))*col , 4) + IncV4*ti((1:col) + (lin-(l-1))*col , 4)) ...
                        + max(IncV2*ti((1:col) + (lin-l)*col , 2));
        PO( (1:col) + (lin-l)*col , 2) = referV;
    end;
    
    % Now I renormalize the widths and heights:
    
    referH  = referH + max(po(col*(0:(lin-1)) + col , 3) + IncH3*ti(col*(0:(lin-1)) + col , 3));
    PO(:,3) = PO(:,3) + (1-referH)/col;
    
    referV  = referV + max(po(1:col , 4) + IncV4*ti(1:col , 4));
    PO(:,4) = PO(:,4) + (1-referV)/lin;
    
    for c=2:col
        PO( col*(0:(lin-1)) + c , 1) = PO( col*(0:(lin-1)) + c , 1) + (c-1)*(1-referH)/col;
    end;
    
    for l=2:lin
        PO( (1:col) + (lin-l)*col , 2) = PO( (1:col) + (lin-l)*col , 2) + (l-1)*(1-referV)/lin;
    end;


    % Now I draw the plots:
    
    ColRange = {'k', 'b', 'r'};
    TypRange = {'-', '--', ':'};
        
    co1 = '-k';
    co2a = '*k';
    co2b = 'sk';
    
    sfN     = sf/sf(1,1);
    sfN_PiY = sf_PiY/sf(1,1);
    subplot(lin,col,1);
        plot(piY, sfN, co1); hold on;
        plot(pi_Year, sfN_PiY, co2a); plot(pi_Year, sfN_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('s','FontSize', fonsize);
        % ylim([0.99 1.01]);
        title('Normalized Total Surplus','FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,2);
        plot(piY, w, co1); hold on;
        plot(pi_Year, w_PiY, co2a); plot(pi_Year, w_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('w','FontSize', fonsize);
        % ylim([19 20]);
        title({'Salary';'wage*h'},'FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,3);
        plot(piY, ue*100, co1); hold on;
        plot(pi_Year, 100*ue_PiY, co2a); plot(pi_Year, 100*ue_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('u^e','FontSize', fonsize);
        % ylim([5 6]);
        title({'Unemployment (%)';'End of Period'},'FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,4);
        plot(piY, v*100, co1); hold on;
        plot(pi_Year, 100*v_PiY, co2a); plot(pi_Year, 100*v_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('v','FontSize', fonsize);
        % ylim([10 11]);
        title('Vacancy Postings (%)','FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,5);
        plot(piY, theta, co1); hold on;
        plot(pi_Year, theta_PiY, co2a); plot(pi_Year, theta_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('\theta','FontSize', fonsize);
        % ylim([0.53 0.56]);
        title({'Tightness Ratio';'Beggining of Period'},'FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,6);
        plot(piY, thetae, co1); hold on;
        plot(pi_Year, thetae_PiY, co2a); plot(pi_Year, thetae_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('\theta^e','FontSize', fonsize);
        % ylim([1.7 2.1]);
        title({'Tightness Ratio';'End of Period'},'FontSize', fonsizeTtl);
        % hold off; 
            
    subplot(lin,col,7);
        plot(piY, p*100, co1); hold on;
        plot(pi_Year, p_PiY*100, co2a); plot(pi_Year, p_PiY*100, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('p','FontSize', fonsize);
        % ylim([69 73]);
        title('Job-Finding Probability (%)','FontSize', fonsizeTtl);
        % hold off;  

    subplot(lin,col,8);
        plot(piY, q, co1); hold on;
        plot(pi_Year, q_PiY, co2a); plot(pi_Year, q_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('q','FontSize', fonsize);
        % ylim([1.25 1.35]);
        title('Vacancy-Filling Rate','FontSize', fonsizeTtl);
        % hold off; 
            
    subplot(lin,col,9);
        plot(piY, n*100, co1); hold on;
        plot(pi_Year, 100*n_PiY, co2a); plot(pi_Year, 100*n_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('n','FontSize', fonsize);
        % ylim([94 95]);
        title('Employment (%)','FontSize', fonsizeTtl);
        % hold off;
                        
    subplot(lin,col,10);
        plot(piY, h, co1); hold on;
        plot(pi_Year, h_PiY, co2a); plot(pi_Year, h_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('h','FontSize', fonsize);
        % ylim([0.85 1.5]);
        title('Hours per Worker','FontSize', fonsizeTtl);
        % hold off;
            
    subplot(lin,col,11);
        plot(piY, 100*(X-1), co1); hold on;
        plot(pi_Year, 100*(X_PiY-1), co2a); plot(pi_Year, 100*(X_PiY-1), co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('x','FontSize', fonsize);
        % ylim([-20 10]);
        title('Output Gap (%)','FontSize', fonsizeTtl);
        % hold off;
    
    WelfN     = Welf - Welf(1,1);
    WelfN_PiY = Welf_PiY - Welf(1,1);
    subplot(lin,col,12);
        plot(piY, WelfN, co1); hold on;
        plot(pi_Year, WelfN_PiY, co2a); plot(pi_Year, WelfN_PiY, co2b);
        xlabel('Annual Inflation','FontSize', fonsizeTtl);
        ylabel('Welfare','FontSize', fonsize);
        % ylim([-25 2]);
        title('Normalized Welfare','FontSize', fonsizeTtl);
        % hold off;
        
        
    % Now I rescale the subplots:
        
    for index=1:(lin*col)
        subplot(lin,col,index);
        set(gca,'Position',PO(index,:));
    end;

end

